=======
XFaster
=======

.. image:: https://badge.fury.io/py/xfaster.svg
    :target: https://badge.fury.io/py/xfaster

.. image:: https://github.com/SPIDER-CMB/xfaster/actions/workflows/release.yaml/badge.svg
   :target: https://github.com/SPIDER-CMB/xfaster/actions/workflows/release.yaml

.. image:: https://github.com/SPIDER-CMB/xfaster/actions/workflows/documentation.yaml/badge.svg
   :target: https://github.com/SPIDER-CMB/xfaster/actions/workflows/documentation.yaml

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.5248317.svg
   :target: https://doi.org/10.5281/zenodo.5248317
   
Description
-----------

Implementation by A. Gambrel, A. Rahlin, C. Contaldi.

XFaster is a fast power spectrum and likelihood estimator for CMB datasets. It
has most recently been used for the SPIDER B-mode polarization results, but is
intended to be generically useful for modern CMB observatories.

An accompanying paper describing the algorithm can be found here: https://arxiv.org/abs/2104.01172

Documentation can be found here: https://SPIDER-CMB.github.io/xfaster/

xfaster:
    python package

docs:
    documentation on usage, file structure, etc.

example:
    an example configuration for running xfaster


To get started, install xfaster::

    pip install xfaster
